@@ -1,6 +1,8 @@
+import sys
 from itertools import (chain,
                        groupby)
-from typing import (Any,
+from typing import (AbstractSet,
+                    Any,
                     Iterable,
                     List,
                     Sequence,
@@ -10,12 +12,12 @@ from typing import (Any,
 from ground.base import (Context,
                          Orientation)
 from ground.hints import (Contour,
-                          Coordinate,
                           Point,
                           Polygon,
+                          Scalar,
                           Segment)
 
-from .hints import (Multiregion,
+from .hints import (Region,
                     SegmentEndpoints)
 
 
@@ -58,12 +60,6 @@ def contour_to_oriented_edges_endpoints(contour: Contour,
                   for index in range(len(vertices) - 1, -1, -1)))
 
 
-def contour_to_edges_endpoints(contour: Contour) -> Iterable[SegmentEndpoints]:
-    vertices = contour.vertices
-    return ((vertices[index - 1], vertices[index])
-            for index in range(len(vertices)))
-
-
 def to_contour_orientation(contour: Contour, context: Context) -> Orientation:
     vertices = contour.vertices
     index = min(range(len(vertices)),
@@ -79,19 +75,19 @@ def to_first_border_vertex(polygon: Polygon) -> Point:
     return polygon.border.vertices[0]
 
 
-def to_multiregion_x_max(multiregion: Multiregion) -> Coordinate:
+def to_regions_x_max(regions: Sequence[Region]) -> Scalar:
     return max(vertex.x
-               for border in multiregion
+               for border in regions
                for vertex in border.vertices)
 
 
-def to_polygons_x_max(polygons: Sequence[Polygon]) -> Coordinate:
+def to_polygons_x_max(polygons: Sequence[Polygon]) -> Scalar:
     return max(vertex.x
                for polygon in polygons
                for vertex in polygon.border.vertices)
 
 
-def to_segments_x_max(segments: Sequence[Segment]) -> Coordinate:
+def to_segments_x_max(segments: Sequence[Segment]) -> Scalar:
     return max(max(segment.start.x, segment.end.x) for segment in segments)
 
 
@@ -121,3 +117,17 @@ def endpoints_to_segments(endpoints: Iterable[SegmentEndpoints],
                           context: Context) -> Sequence[Segment]:
     segment_cls = context.segment_cls
     return [segment_cls(start, end) for start, end in endpoints]
+
+
+def to_endpoints(segment: Segment) -> SegmentEndpoints:
+    return segment.start, segment.end
+
+
+if sys.version_info < (3, 6):
+    from collections import OrderedDict
+else:
+    OrderedDict = dict
+
+
+def to_ordered_set(values: Iterable[_T]) -> AbstractSet[_T]:
+    return OrderedDict.fromkeys(values).keys()
